PAWpySeed: funcset Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
funcset Struct Reference

`#include <utils.h>`

## Public Attributes
int | l
| l quantum number More...
double * | proj
| projector function More...
double ** | proj_spline
| projector function spline More...
double * | aewave
| all electron partial wave More...
double ** | aewave_spline
| ae partial wave spline coefficients More...
double * | pswave
| pseudo partial wave More...
double ** | pswave_spline
| ps partial wave spline coefficients More...
double * | diffwave
| aewave-pswave More...
double ** | diffwave_spline
| spline coefficients for diffwave More...
double * | kwave
| Expansion of diffwave in spherical Bessel functions. More...
double ** | kwave_spline
| spline coefficients for kwave More...
double * | smooth_diffwave
| diffwave on linear grid with high-frequency components removed More...
double ** | smooth_diffwave_spline
| spline coefficients for smooth_diffwave More...
double * | dense_kwave
double ** | dense_kwave_spline

## Detailed Description

One set of augmentation region functions, i.e. p_i, phi_i, and phit_i (projector, all electron partial wave, and partial wave), as well as the difference of the partial waves, the difference expanded in spherical Bessel functions, and spline coefficients for each grid.

## Member Data Documentation

double* funcset::aewave

all electron partial wave

double** funcset::aewave_spline

ae partial wave spline coefficients

double* funcset::dense_kwave

double** funcset::dense_kwave_spline

double* funcset::diffwave

aewave-pswave

double** funcset::diffwave_spline

spline coefficients for diffwave

double* funcset::kwave

Expansion of diffwave in spherical Bessel functions.

double** funcset::kwave_spline

spline coefficients for kwave

int funcset::l

l quantum number

double* funcset::proj

projector function

double** funcset::proj_spline

projector function spline

double* funcset::pswave

pseudo partial wave

double** funcset::pswave_spline

ps partial wave spline coefficients

double* funcset::smooth_diffwave

diffwave on linear grid with high-frequency components removed

double** funcset::smooth_diffwave_spline

spline coefficients for smooth_diffwave

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h